@@ -1,14 +1,14 @@
 use clap::Parser;
 use rodio::OutputStream;
 use std::fs::File;
-use std::io::BufReader;
+use std::io::{BufReader, Cursor};
 
 #[derive(Parser)]
 #[clap(author, version, about, long_about = None)]
 struct CLI {
-    /// The file you want to play
+    /// The file or the URL you want to play
     #[clap()]
-    file: String,
+    file_or_url: String,
 
     /// Set the volume of the audio
     #[clap(short, long)]
@@ -35,11 +35,38 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 
     let settings = AudioSettings::new(cli.volume, cli.speed);
 
-    match play_audio(cli.file, settings) {
-        Ok(_) => Ok(()),
-
-        Err(_) => panic!("Error! Something went wrong, please try again."),
+    if cli.file_or_url.starts_with("http") {
+        match play_audio_from_url(cli.file_or_url, settings) {
+            Ok(_) => println!("Playing..."),
+            Err(_) => panic!("Error! Something went wrong, please try again."),
+        }
+    } else {
+        match play_audio(cli.file_or_url, settings) {
+            Ok(_) => println!("Playing..."),
+            Err(_) => panic!("Error! Something went wrong, please try again."),
+        }
     }
+
+    Ok(())
+}
+
+fn play_audio_from_url(
+    url: String,
+    settings: AudioSettings,
+) -> Result<(), Box<dyn std::error::Error>> {
+    let response = reqwest::blocking::get(&url).unwrap();
+
+    let cursor = Cursor::new(response.bytes().unwrap());
+
+    let (_stream, stream_handle) = OutputStream::try_default()?;
+
+    let sink = stream_handle.play_once(cursor)?;
+
+    sink.set_volume(settings.volume);
+    sink.set_speed(settings.speed);
+    sink.sleep_until_end();
+
+    Ok(())
 }
 
 fn play_audio(file: String, settings: AudioSettings) -> Result<(), Box<dyn std::error::Error>> {
